import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class IrregularWebcomic(BasicComicModule):
    latestUrl = 'http://www.irregularwebcomic.net/'
    imageUrl = 'http://www.irregularwebcomic.net/cgi-bin/comic.pl?comic=%s'
    imageSearch = re.compile(r'<img .*src="(.*comics/.*(png|jpg|gif))".*>')
    prevSearch = re.compile(r'<a href="(/\d+\.html|/cgi-bin/comic\.pl\?comic=\d+)">Previous ')
    help = 'Index format: nnn'
